@@ -1,21 +1,19 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Invenio.
-# Copyright (C) 2016-2018 CERN.
+# Copyright (C) 2016-2022 CERN.
 #
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
 
 """Record indexer for Invenio."""
 
-from __future__ import absolute_import, print_function
-
 from kombu import Exchange, Queue
 
 INDEXER_DEFAULT_INDEX = "records-record-v1.0.0"
 """Default index to use if no schema is defined."""
 
-INDEXER_DEFAULT_DOC_TYPE = "_doc"
+INDEXER_DEFAULT_DOC_TYPE = "record-v1.0.0"
 """Default doc_type to use if no schema is defined."""
 
 INDEXER_MQ_EXCHANGE = Exchange('indexer', type='direct')
